pub struct CompleteEvent { /* private fields */ }Expand description
A CompleteEvent is the result of making a synchronous ffi call.
After the cl_event’s event is over the event is no longer able
A CompleteEvent is not for putting into WaitList.
Don’t do it. You’ll segfault.
Implementations
Sourceimpl CompleteEvent
impl CompleteEvent